@@ -296,6 +296,13 @@ int mutt_index_menu (void)
     menu->max = Context ? Context->vcount : 0;
     oldcount = Context ? Context->msgcount : 0;
 
+    /* check if we need to resort the index because just about
+     * any 'op' below could do mutt_enter_command(), either here or
+     * from any new menu launched, and change $sort/$sort_aux
+     */
+    if (option (OPTNEEDRESORT) && Context && Context->msgcount)
+      resort_index (menu);
+
     if (Context && !attach_msg)
     {
       int check;
@@ -777,7 +784,7 @@ int mutt_index_menu (void)
 	  /* calculate the number of messages _above_ the cursor,
 	   * so we can keep the cursor on the current message
 	   */ 
-	  for (j = 0; j < menu->current; j++)
+	  for (j = 0; j <= menu->current; j++)
 	  {
 	    if (Context->hdrs[Context->v2r[j]]->deleted)
 	      dcount++;
@@ -946,11 +953,6 @@ int mutt_index_menu (void)
 	  break;
 	}
 
-	if (option (OPTNEEDRESORT) && Context && Context->msgcount)
-	{
-	  resort_index (menu);
-	}
-
 	menu->menu = MENU_PAGER;
 	menu->oldcurrent = menu->current;
 	continue;
@@ -1121,7 +1123,7 @@ int mutt_index_menu (void)
 	    }
 	  }
 
-	  if (CUR->collapsed)
+	  if ((Sort & SORT_MASK) == SORT_THREADS && CUR->collapsed)
 	  {
 	    if ((op == OP_MAIN_NEXT_UNREAD || op == OP_MAIN_PREV_UNREAD) &&
 		UNREAD (CUR))
@@ -1458,10 +1460,6 @@ int mutt_index_menu (void)
 	CurrentMenu = MENU_MAIN;
 	mutt_enter_command ();
 	mutt_check_rescore (Context);
-	if (option (OPTNEEDRESORT) && Context && Context->msgcount)
-	{
-	  resort_index (menu);
-	}
 	if (option (OPTFORCEREDRAWINDEX))
 	  menu->redraw = REDRAW_FULL;
 	unset_option (OPTFORCEREDRAWINDEX);
