@@ -274,13 +274,17 @@ void menu_redraw_current (MUTTMENU *menu)
 
 void menu_check_recenter (MUTTMENU *menu)
 {
-  if (menu->current >= menu->top + menu->pagelen)
+  if (menu->max <= menu->pagelen)
+  {
+    menu->top = 0;
+    set_option (OPTNEEDREDRAW);
+  }
+  else if (menu->current >= menu->top + menu->pagelen)
   {
     if (option (OPTMENUSCROLL))
       menu->top = menu->current - menu->pagelen + 1;
     else
       menu->top += menu->pagelen * ((menu->current - menu->top) / menu->pagelen);
-    menu->redraw = REDRAW_INDEX;
   }
   else if (menu->current < menu->top)
   {
@@ -292,8 +296,8 @@ void menu_check_recenter (MUTTMENU *menu)
       if (menu->top < 0)
 	menu->top = 0;
     }
-    menu->redraw = REDRAW_INDEX;
   }
+  menu->redraw |= REDRAW_INDEX;
 }
 
 void menu_jump (MUTTMENU *menu)
